@@ -4,8 +4,8 @@ import shutil, os, pathlib
 def read(my_file_path):
     my_error = ""
     # 判断绝对路径
-    if not os.path.isabs(my_file_path):
-        my_error = my_error + f"1请检查路径是不是绝对路径|      {my_file_path}"
+    # if not os.path.isabs(my_file_path):
+    #     my_error = my_error + f"1请检查路径是不是绝对路径|      {my_file_path}"
 
     # 判断存在文件吗
     if not os.path.exists(my_file_path):
